==> webkitgtk_2.3.2.orig.tar.xz: webkitgtk-2.3.2/Source/WebCore/dom/BeforeUnloadEvent.h <==
/*
 * Copyright (C) 2001 Peter Kelly (pmk@post.com)
 * Copyright (C) 2001 Tobias Anton (anton@stud.fbi.fh-darmstadt.de)
 * Copyright (C) 2006 Samuel Weinig (sam.weinig@gmail.com)
 * Copyright (C) 2003, 2004, 2005, 2006 Apple Computer, Inc.
 * Copyright (C) 2013 Samsung Electronics
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 *
 */

#ifndef BeforeUnloadEvent_h
#define BeforeUnloadEvent_h

#include "Event.h"

namespace WebCore {

class BeforeUnloadEvent FINAL : public Event {
public:
    virtual ~BeforeUnloadEvent();

    static PassRefPtr<BeforeUnloadEvent> create()
    {
        return adoptRef(new BeforeUnloadEvent);
    }

    String returnValue() const { return m_returnValue; }
    void setReturnValue(const String& returnValue) { m_returnValue = returnValue; }

    virtual EventInterface eventInterface() const OVERRIDE { return BeforeUnloadEventInterfaceType; }

private:
    BeforeUnloadEvent();

    virtual bool isBeforeUnloadEvent() const OVERRIDE;

    String m_returnValue;
};

inline BeforeUnloadEvent* toBeforeUnloadEvent(Event* event)
{
    ASSERT_WITH_SECURITY_IMPLICATION(!event || event->isBeforeUnloadEvent());
    return static_cast<BeforeUnloadEvent*>(event);
}

} // namespace WebCore

#endif // BeforeUnloadEvent_h

==> webkitgtk-2.6.5.tar.xz: webkitgtk-2.6.5/Source/WebCore/dom/BeforeUnloadEvent.h <==
/*
 * Copyright (C) 2001 Peter Kelly (pmk@post.com)
 * Copyright (C) 2001 Tobias Anton (anton@stud.fbi.fh-darmstadt.de)
 * Copyright (C) 2006 Samuel Weinig (sam.weinig@gmail.com)
 * Copyright (C) 2003, 2004, 2005, 2006 Apple Inc.
 * Copyright (C) 2013 Samsung Electronics
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 *
 */

#ifndef BeforeUnloadEvent_h
#define BeforeUnloadEvent_h

#include "Event.h"

namespace WebCore {

class BeforeUnloadEvent final : public Event {
public:
    virtual ~BeforeUnloadEvent();

    static PassRefPtr<BeforeUnloadEvent> create()
    {
        return adoptRef(new BeforeUnloadEvent);
    }

    String returnValue() const { return m_returnValue; }
    void setReturnValue(const String& returnValue) { m_returnValue = returnValue; }

    virtual EventInterface eventInterface() const override { return BeforeUnloadEventInterfaceType; }

private:
    BeforeUnloadEvent();

    virtual bool isBeforeUnloadEvent() const override;

    String m_returnValue;
};

EVENT_TYPE_CASTS(BeforeUnloadEvent)

} // namespace WebCore

#endif // BeforeUnloadEvent_h
